@@ -1,22 +1,11 @@
 /***************************************************************************
  *
- * Copyright (c) 2000,2001,2002 BalaBit IT Ltd, Budapest, Hungary
+ * This file is covered by a dual licence. You can choose whether you
+ * want to use it according to the terms of the GNU GPL version 2, or
+ * under the terms of Zorp Professional Firewall System EULA located
+ * on the Zorp installation CD.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- * $Id: listen.h,v 1.7.2.1 2003/04/11 19:15:54 sasa Exp $
+ * $Id: listen.h,v 1.11 2004/10/05 14:06:37 chaoron Exp $
  *
  ***************************************************************************/
 
@@ -42,16 +31,18 @@ extern "C" {
 typedef struct _ZIOListen 
 {
   ZSockAddr *local;
+  gint fd;
 } ZIOListen;
 
 typedef gboolean (*ZAcceptFunc)(int fd, ZSockAddr *client, gboolean last_connection, gpointer user_data);
 
 ZIOListen *
-z_io_listen_new(ZSockAddr *local, 
-		     gboolean accept_one,
-		     gint backlog,
-		     ZAcceptFunc callback,
-		     gpointer user_data);
+z_io_listen_new(const gchar *session_id,
+                ZSockAddr *local,
+		guint32 sock_flags,
+		gint backlog,
+		ZAcceptFunc callback,
+		gpointer user_data);
 
 void z_io_listen_ref(ZIOListen *l);
 void z_io_listen_unref(ZIOListen *l);
@@ -61,6 +52,8 @@ void z_io_listen_cancel(ZIOListen *l);
 void z_io_listen_suspend(ZIOListen *l);
 void z_io_listen_resume(ZIOListen *l);
 
+G_CONST_RETURN gchar *z_io_listen_get_session(ZIOListen *l);
+
 #ifdef __cplusplus
 }
 #endif
